@@ -95,7 +95,7 @@ find_statistic <- function(x, ...) {
     "HLfit", "hglm",
     "ivreg", "ivFixed", "iv_robust", "ivprobit",
     "lm", "lm_robust", "lm.beta", "lme", "lmerMod", "lmerModLmerTest",
-    "lmodel2", "lmRob", "lmrob", "lqm", "lqmm",
+    "lmodel2", "lmRob", "lmrob", "lqm", "lqmm", "lm_weightit",
     "maxLik", "mixed", "mhurdle", "mlm", "mmrm", "mmrm_fit",
     "mmrm_tmb",
     "nlmerMod", "nlrq", "nls",
@@ -117,7 +117,7 @@ find_statistic <- function(x, ...) {
     "betamfx", "betaor", "betareg", "bife", "bifeAPEs", "bglmerMod",
     "boot_test_mediation", "bracl", "brglm", "brglmFit", "brmultinom", "btergm",
     "cglm", "cph", "clm", "clm2", "clmm", "clmm2", "clogit", "coxme", "coxph",
-    "coxr", "crch", "crr",
+    "coxr", "crch", "crr", "coxph_weightit",
     "deltaMethod", "DirichletRegModel",
     "ergm",
     "feglm", "flexsurvreg",
@@ -127,9 +127,9 @@ find_statistic <- function(x, ...) {
     "lavaan", "loggammacenslmrob", "logitmfx", "logitor", "logitr", "LORgee", "lrm",
     "margins", "marginaleffects", "marginaleffects.summary", "metaplus", "mixor",
     "MixMod", "mjoint", "mle", "mle2", "mlogit", "mblogit", "mclogit", "mmclogit",
-    "multinom", "mvmeta", "mvord",
+    "multinom", "mvmeta", "mvord", "multinom_weightit",
     "negbin", "negbinmfx", "negbinirr", "nlreg", "nestedLogit",
-    "objectiveML", "orm",
+    "objectiveML", "orm", "ordinal_weightit",
     "poissonmfx", "poissonirr", "psm", "probitmfx", "pgmm", "phyloglm",
     "qr", "QRNLMM", "QRLMM",
     "Rchoice", "riskRegression", "robmixglm", "rma", "rma.mv", "rma.uni", "rrvglm",
@@ -175,7 +175,7 @@ find_statistic <- function(x, ...) {
       "bam", "bigglm",
       "cgam", "cgamm",
       "eglm", "emmGrid", "emm_list",
-      "gam", "glm", "Glm", "glmc", "glmerMod", "glmRob", "glmrob",
+      "gam", "glm", "Glm", "glmc", "glmerMod", "glmRob", "glmrob", "glm_weightit",
       "pseudoglm",
       "scam",
       "speedglm"
