@@ -795,6 +795,14 @@ get_statistic.clm2 <- function(x, component = "all", ...) {
 get_statistic.clmm2 <- get_statistic.clm2
 
 
+#' @export
+get_statistic.ordinal_weightit <- function(x, ...) {
+  out <- get_statistic.default(x, ...)
+  out$Component <- "conditional"
+  out
+}
+
+
 #' @export
 get_statistic.mvord <- function(x, component = "all", ...) {
   component <- match.arg(
@@ -924,6 +932,26 @@ get_statistic.multinom <- function(x, ...) {
 #' @export
 get_statistic.brmultinom <- get_statistic.multinom
 
+#' @export
+get_statistic.multinom_weightit <- function(x, ...) {
+  parms <- get_parameters(x)
+  cs <- suppressWarnings(stats::coef(summary(x)))
+
+  out <- data.frame(
+    Parameter = parms$Parameter,
+    Statistic = as.vector(cs[, 3]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  if ("Response" %in% colnames(parms)) {
+    out$Response <- parms$Response
+  }
+
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
 
 #' @export
 get_statistic.bracl <- function(x, ...) {
