@@ -37,19 +37,16 @@ test_that("find_response", {
 })
 
 test_that("get_response", {
-  expect_equal(get_response(m1), stackloss$stack.loss)
+  expect_identical(get_response(m1), stackloss$stack.loss)
 })
 
 test_that("get_predictors", {
-  expect_equal(colnames(get_predictors(m1)), c("Air.Flow", "Water.Temp"))
+  expect_named(get_predictors(m1), c("Air.Flow", "Water.Temp"))
 })
 
 test_that("get_data", {
-  expect_equal(nrow(get_data(m1)), 21)
-  expect_equal(
-    colnames(get_data(m1)),
-    c("stack.loss", "Air.Flow", "Water.Temp")
-  )
+  expect_identical(nrow(get_data(m1)), 21L)
+  expect_named(get_data(m1), c("stack.loss", "Air.Flow", "Water.Temp"))
 })
 
 test_that("find_formula", {
@@ -62,21 +59,21 @@ test_that("find_formula", {
 })
 
 test_that("find_terms", {
-  expect_equal(
+  expect_identical(
     find_terms(m1),
     list(
       response = "stack.loss",
       conditional = c("Air.Flow", "Water.Temp")
     )
   )
-  expect_equal(
+  expect_identical(
     find_terms(m1, flatten = TRUE),
     c("stack.loss", "Air.Flow", "Water.Temp")
   )
 })
 
 test_that("n_obs", {
-  expect_equal(n_obs(m1), 21)
+  expect_identical(n_obs(m1), 21L)
 })
 
 test_that("link_function", {
@@ -88,14 +85,14 @@ test_that("link_inverse", {
 })
 
 test_that("find_parameters", {
-  expect_equal(
+  expect_identical(
     find_parameters(m1),
     list(conditional = c(
       "(Intercept)", "Air.Flow", "Water.Temp"
     ))
   )
-  expect_equal(nrow(get_parameters(m1)), 3)
-  expect_equal(
+  expect_identical(nrow(get_parameters(m1)), 3L)
+  expect_identical(
     get_parameters(m1)$Parameter,
     c("(Intercept)", "Air.Flow", "Water.Temp")
   )
@@ -106,7 +103,7 @@ test_that("is_multivariate", {
 })
 
 test_that("find_algorithm", {
-  expect_equal(find_algorithm(m1), list(algorithm = "br"))
+  expect_identical(find_algorithm(m1), list(algorithm = "br"))
 })
 
 test_that("find_statistic", {
